@@ -578,8 +578,6 @@ static char *doc_PkgSystemLockInner =
 "Reacquire the dpkg 'lock' lock file. Must be called only after\n"
 ":meth:`pkgsystem_unlock_inner` and only around invocations of dpkg.\n"
 "\n"
-".. versionadded:: 1.6.3\n"
-"\n"
 ".. versionadded:: 1.7";
 static PyObject *PkgSystemLockInner(PyObject *Self,PyObject *Args)
 {
@@ -597,8 +595,6 @@ static char *doc_PkgSystemUnLockInner =
 "Release the dpkg lock file 'lock'. To be called before manually\n"
 "invoking dpkg.\n"
 "\n"
-".. versionadded:: 1.6.3\n"
-"\n"
 ".. versionadded:: 1.7";
 static PyObject *PkgSystemUnLockInner(PyObject *Self,PyObject *Args)
 {
@@ -616,8 +612,6 @@ static char *doc_PkgSystemIsLocked =
 "Check if the system is locked. Can be used to check whether the inner\n"
 "lock needs to be released or not in generic code.\n"
 "\n"
-".. versionadded:: 1.6.3\n"
-"\n"
 ".. versionadded:: 1.7";
 static PyObject *PkgSystemIsLocked(PyObject *Self,PyObject *Args)
 {
@@ -649,7 +643,6 @@ static PyMethodDef methods[] =
     "and only does translations after setlocale() has been called."},
 
    // Tag File
-   {"rewrite_section",RewriteSection,METH_VARARGS,doc_RewriteSection},
 
    {"open_maybe_clear_signed_file",PyOpenMaybeClearSignedFile,METH_VARARGS,
     doc_OpenMaybeClearSignedFile},
