@@ -251,7 +251,10 @@ class TestAptSources(testcommon.TestCase):
         apt_pkg.config.set("Dir::Etc::sourcelist", "data/aptsources/"
                            "sources.list.testDistribution")
         sources = aptsources.sourceslist.SourcesList(True, self.templates)
-        distro = aptsources.distro.get_distro(id="Ubuntu")
+        distro = aptsources.distro.get_distro(id="Ubuntu",
+                                              codename="bionic",
+                                              description="Ubuntu 18.04 LTS",
+                                              release="18.04")
         distro.get_sources(sources)
         # test if all suits of the current distro were detected correctly
         for s in sources:
@@ -317,7 +320,10 @@ class TestAptSources(testcommon.TestCase):
         apt_pkg.config.set("Dir::Etc::sourcelist", "data/aptsources/"
                            "sources.list.testDistribution")
         sources = aptsources.sourceslist.SourcesList(True, self.templates)
-        distro = aptsources.distro.get_distro(id="Ubuntu")
+        distro = aptsources.distro.get_distro(id="Ubuntu",
+                                              codename="bionic",
+                                              description="Ubuntu 18.04 LTS",
+                                              release="18.04")
         distro.get_sources(sources)
         # test if all suits of the current distro were detected correctly
         dist_templates = set()
